lcvtoolbox.core.schemas.UTMPolygonResult
========================================

.. currentmodule:: lcvtoolbox.core.schemas

.. autoclass:: UTMPolygonResult
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:
   :special-members: __init__, __str__, __repr__

   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~UTMPolygonResult.__init__
      ~UTMPolygonResult.construct
      ~UTMPolygonResult.copy
      ~UTMPolygonResult.dict
      ~UTMPolygonResult.from_orm
      ~UTMPolygonResult.json
      ~UTMPolygonResult.model_construct
      ~UTMPolygonResult.model_copy
      ~UTMPolygonResult.model_dump
      ~UTMPolygonResult.model_dump_json
      ~UTMPolygonResult.model_json_schema
      ~UTMPolygonResult.model_parametrized_name
      ~UTMPolygonResult.model_post_init
      ~UTMPolygonResult.model_rebuild
      ~UTMPolygonResult.model_validate
      ~UTMPolygonResult.model_validate_json
      ~UTMPolygonResult.model_validate_strings
      ~UTMPolygonResult.parse_file
      ~UTMPolygonResult.parse_obj
      ~UTMPolygonResult.parse_raw
      ~UTMPolygonResult.schema
      ~UTMPolygonResult.schema_json
      ~UTMPolygonResult.update_forward_refs
      ~UTMPolygonResult.validate
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~UTMPolygonResult.model_computed_fields
      ~UTMPolygonResult.model_config
      ~UTMPolygonResult.model_extra
      ~UTMPolygonResult.model_fields
      ~UTMPolygonResult.model_fields_set
      ~UTMPolygonResult.polygon
      ~UTMPolygonResult.zone_number
      ~UTMPolygonResult.zone_letter
   
   